@@ -195,11 +195,11 @@ class CommonBrowserView(BrowserView):
         else:
             samedate = event.start().strftime('%d - %m - %Y') == event.end().strftime('%d - %m - %Y')
             
-        finalDatesFmt = '<div class="dates %(class)s"><span class="dateText">%(dates)s %(hours)s</span></div>'
+        finalDatesFmt = '<div class="dates %(class)s"><span class="dateText">%(dates)s%(hours)s</span></div>'
         
         dates = "%s"%(samedate and (event.start() is not None and event.start().strftime('%A, %d %B %Y') or event.end().strftime('%A, %d %B %Y')) or "%s to %s"%(event.start().strftime('%A, %d %B %Y'), event.end().strftime('%A, %d %B %Y')))
         
-        openingHour = event.start() is None and event.start().strftime('%H:%M') or "00:00"
+        openingHour = event.start() is not None and event.start().strftime('%H:%M') or "00:00"
         closingHour = event.end() is not None and event.end().strftime('%H:%M') or "00:00"
         hoursExist = openingHour != closingHour
         
